@@ -16,30 +16,26 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-
 #include "loginfo.h"
 
-#include <qtextdocument.h>
 #include <QLocale>
+#include <qtextdocument.h>
 
 #include <KLocalizedString>
 
 namespace Cervisia
 {
 
-
-TagInfo::TagInfo(const QString& name, Type type)
-    : m_name(name),
-      m_type(type)
+TagInfo::TagInfo(const QString &name, Type type)
+    : m_name(name)
+    , m_type(type)
 {
 }
 
-
 QString TagInfo::toString(bool prefixWithType) const
 {
     QString text;
-    if (prefixWithType)
-    {
+    if (prefixWithType) {
         text += typeToString() + QLatin1String(": ");
     }
     text += m_name;
@@ -47,12 +43,10 @@ QString TagInfo::toString(bool prefixWithType) const
     return text;
 }
 
-
 QString TagInfo::typeToString() const
 {
     QString text;
-    switch (m_type)
-    {
+    switch (m_type) {
     case Branch:
         text = i18n("Branchpoint");
         break;
@@ -67,7 +61,6 @@ QString TagInfo::typeToString() const
     return text;
 }
 
-
 QString LogInfo::createToolTipText(bool showTime) const
 {
     QString text(QLatin1String("<nobr><b>"));
@@ -78,19 +71,15 @@ QString LogInfo::createToolTipText(bool showTime) const
     text += dateTimeToString(showTime).toHtmlEscaped();
     text += QLatin1String("</b></nobr>");
 
-    if (!m_comment.isEmpty())
-    {
+    if (!m_comment.isEmpty()) {
         text += QLatin1String("<pre>");
         text += m_comment.toHtmlEscaped();
         text += QLatin1String("</pre>");
     }
 
-    if (!m_tags.isEmpty())
-    {
+    if (!m_tags.isEmpty()) {
         text += QLatin1String("<i>");
-        for (TTagInfoSeq::const_iterator it = m_tags.begin();
-             it != m_tags.end(); ++it)
-        {
+        for (TTagInfoSeq::const_iterator it = m_tags.begin(); it != m_tags.end(); ++it) {
             if (it != m_tags.begin() || m_comment.isEmpty())
                 text += QLatin1String("<br>");
             text += (*it).toString().toHtmlEscaped();
@@ -101,31 +90,23 @@ QString LogInfo::createToolTipText(bool showTime) const
     return text;
 }
 
-
 QString LogInfo::dateTimeToString(bool showTime, bool shortFormat) const
 {
     QLocale::FormatType format = shortFormat ? QLocale::ShortFormat : QLocale::LongFormat;
-    if( showTime )
+    if (showTime)
         return QLocale().toString(m_dateTime, format);
     else
         return QLocale().toString(m_dateTime.date(), format);
 }
 
-
-QString LogInfo::tagsToString(unsigned int types,
-                              unsigned int prefixWithType,
-                              const QString& separator) const
+QString LogInfo::tagsToString(unsigned int types, unsigned int prefixWithType, const QString &separator) const
 {
     QString text;
-    for (TTagInfoSeq::const_iterator it = m_tags.begin();
-         it != m_tags.end(); ++it)
-    {
-        const TagInfo& tagInfo(*it);
+    for (TTagInfoSeq::const_iterator it = m_tags.begin(); it != m_tags.end(); ++it) {
+        const TagInfo &tagInfo(*it);
 
-        if (tagInfo.m_type & types)
-        {
-            if (!text.isEmpty())
-            {
+        if (tagInfo.m_type & types) {
+            if (!text.isEmpty()) {
                 text += separator;
             }
 
@@ -136,5 +117,4 @@ QString LogInfo::tagsToString(unsigned int types,
     return text;
 }
 
-
 } // namespace Cervisia
